Grortir
=======

Application for supporting optimization of production process.

| |Build Status|
| |Coverage Status|
| |Code Issues|
| |Code Health|
| |Scrutinizer Code Quality|
| |PyPI Version|
| |PyPI Downloads|

Getting Started
---------------

Check documentation site:

http://qbahn.github.io/grortir/gettingStarted/

Documentation
-------------

Read the full documentation:

http://qbahn.github.io/grortir
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

For contributors
----------------

Check documentation site:

http://qbahn.github.io/grortir/about/contributing/

.. |Build Status| image:: http://img.shields.io/travis/qbahn/grortir/master.svg
   :target: https://travis-ci.org/qbahn/grortir
.. |Coverage Status| image:: http://img.shields.io/coveralls/qbahn/grortir/master.svg
   :target: https://coveralls.io/r/qbahn/grortir
.. |Code Issues| image:: https://www.quantifiedcode.com/api/v1/project/51365120fa014dbd860e332bbc1bee02/badge.svg
   :target: https://www.quantifiedcode.com/app/project/51365120fa014dbd860e332bbc1bee02
.. |Code Health| image:: https://landscape.io/github/qbahn/grortir/master/landscape.svg?style=flat
   :target: https://landscape.io/github/qbahn/grortir/master
.. |Scrutinizer Code Quality| image:: http://img.shields.io/scrutinizer/g/qbahn/grortir.svg
   :target: https://scrutinizer-ci.com/g/qbahn/grortir/?branch=master
.. |PyPI Version| image:: http://img.shields.io/pypi/v/Grortir.svg
   :target: https://pypi.python.org/pypi/Grortir
.. |PyPI Downloads| image:: http://img.shields.io/pypi/dm/Grortir.svg
   :target: https://pypi.python.org/pypi/Grortir
